# spotPython

## Surrogate Model Based Optimization and Hyperparameter Tuning in Python

* Documentation for spotPython see [Hyperparameter Tuning Cookbook](https://sequential-parameter-optimization.github.io/Hyperparameter-Tuning-Cookbook/), a guide for scikit-learn, PyTorch, river, and spotPython.
* News and updates related to spotPython see [SPOTSeven](https://www.spotseven.de/spot/)


